@@ -753,6 +753,12 @@ func (fc *FlowCollector) updateRecord(record interface{}) error {
 					if site.Policy != nil {
 						current.Policy = site.Policy
 					}
+					if site.Platform != nil && current.Platform != site.Platform {
+						current.Platform = site.Platform
+					}
+					if site.Version != nil && current.Version != site.Version {
+						current.Version = site.Version
+					}
 				}
 			}
 			fc.updateLastHeard(site.Source)
@@ -2768,10 +2774,7 @@ func (fc *FlowCollector) purgeEventSource(eventSource EventSourceRecord) error {
 	return nil
 }
 
-func (fc *FlowCollector) createSiteProcess(name string, site SiteRecord) ProcessRecord {
-	parts := strings.Split(site.Identity, "-")
-	processName := name + "-" + parts[0]
-	processGroupName := name
+func (fc *FlowCollector) createSiteProcess(processGroupName string, processName string, site SiteRecord) ProcessRecord {
 	process := ProcessRecord{}
 	process.RecType = recordNames[Process]
 	process.Identity = uuid.New().String()
@@ -2795,6 +2798,9 @@ func (fc *FlowCollector) needForSiteProcess(flow *FlowRecord, siteId string, sta
 		name = "site-clients"
 	}
 	processName := name + "-" + parts[0]
+	if client && flow.SourceHost != nil {
+		processName = processName + "-" + *flow.SourceHost
+	}
 	diffTime := startTime
 	wait := 120 * oneSecond
 	if fc.startTime > startTime {
@@ -2814,7 +2820,7 @@ func (fc *FlowCollector) needForSiteProcess(flow *FlowRecord, siteId string, sta
 		}
 		if !found {
 			if site, ok := fc.Sites[siteId]; ok {
-				process := fc.createSiteProcess(name, *site)
+				process := fc.createSiteProcess(name, processName, *site)
 				flow.Process = &process.Identity
 				flow.ProcessName = &processName
 				found = true
